TStore class

Constructors

TStore(String storeName)

Properties

count → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
isConnected → bool
no setter
isConnecting → bool
no setter
onChanges → Stream<TStoreChanges>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storeName → String
final

Methods

clear() → Future<void>
connect() → Future<bool>
delete(String key) → Future<void>
deleteAll(Iterable<String> keys) → Future<void>
disconnect() → Future<bool>
find(bool finder(dynamic)) → Future<List>
findEntity(bool finder(Map<String, dynamic>)) → Future<List<Map<String, dynamic>>>
list<V>() → Future<List<V>>
listKeys() → Future<List<String>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
persist(String key, dynamic value) → Future<void>
persistAll(Map<String, dynamic> map) → Future<void>
persistEntity(String key, TEntity entity) → Future<void>
retrieve(String key) → Future
retrieveEntity(String key) → Future<Map<String, dynamic>?>
toMap<V>() → Future<Map<String, V>>
toString() → String
A string representation of this object.
inherited
watch({String? key}) → Stream<BoxEvent>?

Operators

operator ==(Object other) → bool
The equality operator.
inherited